NewRanks: This is the file according to quantreg, but adjusted for...

NewRanksR Documentation

This is the file according to quantreg, but adjusted for LiQRAT. It takes the sparse matrix dsol[,1:(J-1)] - dsol[,2:J]

Description

This is the file according to quantreg, but adjusted for LiQRAT. It takes the sparse matrix dsol[,1:(J-1)] - dsol[,2:J]

Usage

NewRanks(v, score = "wilcoxon", Delta = NULL)

tianyingw/iQRAT documentation built on Aug. 22, 2022, 11:25 a.m.