Null_model: Fit the null model This function provides null model fit. The...

View source: R/Null_model.R

Null_modelR Documentation

Fit the null model This function provides null model fit. The default option is to use quantreg since it is faster. When dataset is too large, quantreg will have memory limitation issue, and we will use the self-implemented algorithm.

Description

Fit the null model This function provides null model fit. The default option is to use quantreg since it is faster. When dataset is too large, quantreg will have memory limitation issue, and we will use the self-implemented algorithm.

Usage

Null_model(Y, C)

Arguments

Y

A vector of response, size n.

C

A vector or matrix of covariates.


tianyingw/iQRAT documentation built on Aug. 22, 2022, 11:25 a.m.