| Null_model | R Documentation |
Fit the null model This function provides null model fit. The default option is to use quantreg since it is faster. When dataset is too large, quantreg will have memory limitation issue, and we will use the self-implemented algorithm.
Null_model(Y, C)
Y |
A vector of response, size n. |
C |
A vector or matrix of covariates. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.